@@ -7,7 +7,7 @@ import os
 import site
 import sys
 from pathlib import Path
-from sysconfig import get_paths, get_python_version
+from sysconfig import get_paths, get_python_version, get_scheme_names
 
 import pkg_resources
 
@@ -174,6 +174,15 @@ class Environment:
             return os.path.join(base, leaf)
         return path
 
+    @cached_property
+    def install_scheme(self):
+        if "venv" in get_scheme_names():
+            return "venv"
+        elif os.name == "nt":
+            return "nt"
+        else:
+            return "posix_prefix"
+
     @cached_property
     def base_paths(self):
         # type: () -> Dict[str, str]
@@ -213,9 +222,8 @@ class Environment:
             try:
                 paths = self.get_paths()
             except Exception:
-                install_scheme = "nt" if (os.name == "nt") else "posix_prefix"
                 paths = get_paths(
-                    install_scheme,
+                    self.install_scheme,
                     vars={
                         "base": prefix,
                         "platbase": prefix,
@@ -236,9 +244,8 @@ class Environment:
                     paths.update(self.get_lib_paths())
                     paths["scripts"] = self.script_basedir
         if not paths:
-            install_scheme = "nt" if (os.name == "nt") else "posix_prefix"
             paths = get_paths(
-                install_scheme,
+                self.install_scheme,
                 vars={
                     "base": prefix,
                     "platbase": prefix,
@@ -266,9 +273,8 @@ class Environment:
         # type: () -> str
         """Path to the environment scripts dir"""
         prefix = make_posix(self.prefix.as_posix())
-        install_scheme = "nt" if (os.name == "nt") else "posix_prefix"
         paths = get_paths(
-            install_scheme,
+            self.install_scheme,
             vars={
                 "base": prefix,
                 "platbase": prefix,
@@ -410,8 +416,8 @@ class Environment:
                     paths[key] = make_posix(paths[key])
             return paths
         else:
-            click.echo(f"Failed to load paths: {c.stderr}", fg="yellow")
-            click.echo(f"Output: {c.stdout}", fg="yellow")
+            click.secho(f"Failed to load paths: {c.stderr}", fg="yellow")
+            click.secho(f"Output: {c.stdout}", fg="yellow")
         return None
 
     def get_lib_paths(self):
@@ -840,9 +846,7 @@ class Environment:
         if match is not None:
             if req.editable and req.line_instance.is_local and self.find_egg(match):
                 requested_path = req.line_instance.path
-                return requested_path and vistir.compat.samefile(
-                    requested_path, match.location
-                )
+                return requested_path and os.path.samefile(requested_path, match.location)
             elif match.has_metadata("direct_url.json"):
                 direct_url_metadata = json.loads(match.get_metadata("direct_url.json"))
                 commit_id = direct_url_metadata.get("vcs_info", {}).get("commit_id", "")
