@@ -3,14 +3,12 @@
 
 import logging
 import os
-import sys
 from distutils.util import change_root
 from typing import List, Optional, Sequence
 
 from pipenv.patched.notpip._internal.build_env import BuildEnvironment
-from pipenv.patched.notpip._internal.exceptions import InstallationError
+from pipenv.patched.notpip._internal.exceptions import InstallationError, LegacyInstallFailure
 from pipenv.patched.notpip._internal.models.scheme import Scheme
-from pipenv.patched.notpip._internal.utils.logging import indent_log
 from pipenv.patched.notpip._internal.utils.misc import ensure_dir
 from pipenv.patched.notpip._internal.utils.setuptools_build import make_setuptools_install_args
 from pipenv.patched.notpip._internal.utils.subprocess import runner_with_spinner_message
@@ -19,19 +17,12 @@ from pipenv.patched.notpip._internal.utils.temp_dir import TempDirectory
 logger = logging.getLogger(__name__)
 
 
-class LegacyInstallFailure(Exception):
-    def __init__(self):
-        # type: () -> None
-        self.parent = sys.exc_info()
-
-
 def write_installed_files_from_setuptools_record(
     record_lines: List[str],
     root: Optional[str],
     req_description: str,
 ) -> None:
-    def prepend_root(path):
-        # type: (str) -> str
+    def prepend_root(path: str) -> str:
         if root is None or not os.path.isabs(path):
             return path
         else:
@@ -39,7 +30,7 @@ def write_installed_files_from_setuptools_record(
 
     for line in record_lines:
         directory = os.path.dirname(line)
-        if directory.endswith('.egg-info'):
+        if directory.endswith(".egg-info"):
             egg_info_dir = prepend_root(directory)
             break
     else:
@@ -55,39 +46,36 @@ def write_installed_files_from_setuptools_record(
         filename = line.strip()
         if os.path.isdir(filename):
             filename += os.path.sep
-        new_lines.append(
-            os.path.relpath(prepend_root(filename), egg_info_dir)
-        )
+        new_lines.append(os.path.relpath(prepend_root(filename), egg_info_dir))
     new_lines.sort()
     ensure_dir(egg_info_dir)
-    inst_files_path = os.path.join(egg_info_dir, 'installed-files.txt')
-    with open(inst_files_path, 'w') as f:
-        f.write('\n'.join(new_lines) + '\n')
+    inst_files_path = os.path.join(egg_info_dir, "installed-files.txt")
+    with open(inst_files_path, "w") as f:
+        f.write("\n".join(new_lines) + "\n")
 
 
 def install(
-    install_options,  # type: List[str]
-    global_options,  # type: Sequence[str]
-    root,  # type: Optional[str]
-    home,  # type: Optional[str]
-    prefix,  # type: Optional[str]
-    use_user_site,  # type: bool
-    pycompile,  # type: bool
-    scheme,  # type: Scheme
-    setup_py_path,  # type: str
-    isolated,  # type: bool
-    req_name,  # type: str
-    build_env,  # type: BuildEnvironment
-    unpacked_source_directory,  # type: str
-    req_description,  # type: str
-):
-    # type: (...) -> bool
+    install_options: List[str],
+    global_options: Sequence[str],
+    root: Optional[str],
+    home: Optional[str],
+    prefix: Optional[str],
+    use_user_site: bool,
+    pycompile: bool,
+    scheme: Scheme,
+    setup_py_path: str,
+    isolated: bool,
+    req_name: str,
+    build_env: BuildEnvironment,
+    unpacked_source_directory: str,
+    req_description: str,
+) -> bool:
 
     header_dir = scheme.headers
 
     with TempDirectory(kind="record") as temp_dir:
         try:
-            record_filename = os.path.join(temp_dir.path, 'install-record.txt')
+            record_filename = os.path.join(temp_dir.path, "install-record.txt")
             install_args = make_setuptools_install_args(
                 setup_py_path,
                 global_options=global_options,
@@ -105,20 +93,20 @@ def install(
             runner = runner_with_spinner_message(
                 f"Running setup.py install for {req_name}"
             )
-            with indent_log(), build_env:
+            with build_env:
                 runner(
                     cmd=install_args,
                     cwd=unpacked_source_directory,
                 )
 
             if not os.path.exists(record_filename):
-                logger.debug('Record file %s not found', record_filename)
+                logger.debug("Record file %s not found", record_filename)
                 # Signal to the caller that we didn't install the new package
                 return False
 
-        except Exception:
+        except Exception as e:
             # Signal to the caller that we didn't install the new package
-            raise LegacyInstallFailure
+            raise LegacyInstallFailure(package_details=req_name) from e
 
         # At this point, we have successfully installed the requirement.
 
